@@ -231,7 +231,8 @@ photoset_list_ready_cb (GObject      *source_object,
 	if (error != NULL) {
 		if (data->conn != NULL)
 			gth_task_dialog (GTH_TASK (data->conn), TRUE, NULL);
-		_gtk_error_dialog_from_gerror_run (GTK_WINDOW (data->browser), _("Could not connect to the server"), &error);
+		_gtk_error_dialog_from_gerror_run (GTK_WINDOW (data->browser), _("Could not connect to the server"), error);
+		g_clear_error (&error);
 		gtk_widget_destroy (data->dialog);
 		return;
 	}
@@ -353,7 +354,8 @@ list_photos_ready_cb (GObject      *source_object,
 	if (error != NULL) {
 		if (data->conn != NULL)
 			gth_task_dialog (GTH_TASK (data->conn), TRUE, NULL);
-		_gtk_error_dialog_from_gerror_show (GTK_WINDOW (data->browser), _("Could not get the photo list"), &error);
+		_gtk_error_dialog_from_gerror_show (GTK_WINDOW (data->browser), _("Could not get the photo list"), error);
+		g_clear_error (&error);
 		gtk_widget_destroy (data->dialog);
 		return;
 	}
@@ -425,7 +427,7 @@ photoset_combobox_changed_cb (GtkComboBox *widget,
 }
 
 
-static GdkPixbufAnimation *
+static GthImage *
 flickr_thumbnail_loader (GthFileData   *file_data,
 			 int            requested_size,
 			 int           *original_width,
@@ -434,10 +436,10 @@ flickr_thumbnail_loader (GthFileData   *file_data,
 			 GCancellable  *cancellable,
 		         GError       **error)
 {
-	GdkPixbufAnimation *animation = NULL;
-	GthThumbLoader     *thumb_loader = user_data;
-	FlickrPhoto        *photo;
-	const char         *uri = NULL;
+	GthImage       *image = NULL;
+	GthThumbLoader *thumb_loader = user_data;
+	FlickrPhoto    *photo;
+	const char     *uri = NULL;
 
 	photo = (FlickrPhoto *) g_file_info_get_attribute_object (file_data->info, "flickr::object");
 	requested_size = gth_thumb_loader_get_requested_size (thumb_loader);
@@ -459,7 +461,7 @@ flickr_thumbnail_loader (GthFileData   *file_data,
 		gsize  size;
 
 		file = g_file_new_for_uri (uri);
-		if (g_load_file_in_buffer (file, &buffer, &size, error)) {
+		if (g_load_file_in_buffer (file, &buffer, &size, cancellable, error)) {
 			GInputStream *stream;
 			GdkPixbuf    *pixbuf;
 
@@ -472,7 +474,7 @@ flickr_thumbnail_loader (GthFileData   *file_data,
 				g_object_unref (pixbuf);
 				pixbuf = rotated;
 
-				animation = gdk_pixbuf_non_anim_new (pixbuf);
+				image = gth_image_new_for_pixbuf (pixbuf);
 			}
 
 			g_object_unref (pixbuf);
@@ -484,7 +486,7 @@ flickr_thumbnail_loader (GthFileData   *file_data,
 	else
 		*error = g_error_new_literal (GTH_ERROR, 0, "cannot generate the thumbnail");
 
-	return animation;
+	return image;
 }
 
 
@@ -508,7 +510,7 @@ flickr_photo_position_func (GthFileData *a,
 
 
 static void
-file_list_selection_changed_cb (GtkIconView *iconview,
+file_list_selection_changed_cb (GthFileView *file_view,
 				gpointer     user_data)
 {
 	update_selection_status ((DialogData *) user_data);
@@ -558,7 +560,7 @@ dlg_import_from_flickr (FlickrServer *server,
 
 	/* Set the widget data */
 
-	data->file_list = gth_file_list_new (GTH_FILE_LIST_TYPE_NORMAL, FALSE);
+	data->file_list = gth_file_list_new (gth_icon_view_new (), GTH_FILE_LIST_TYPE_NORMAL, FALSE);
 	thumb_loader = gth_file_list_get_thumb_loader (GTH_FILE_LIST (data->file_list));
 	gth_thumb_loader_set_use_cache (thumb_loader, FALSE);
 	gth_thumb_loader_set_loader_func (thumb_loader, flickr_thumbnail_loader);
@@ -618,8 +620,8 @@ dlg_import_from_flickr (FlickrServer *server,
 			  "changed",
 			  G_CALLBACK (photoset_combobox_changed_cb),
 			  data);
-	g_signal_connect (G_OBJECT (gth_file_list_get_view (GTH_FILE_LIST (data->file_list))),
-			  "selection_changed",
+	g_signal_connect (gth_file_list_get_view (GTH_FILE_LIST (data->file_list)),
+			  "file-selection-changed",
 			  G_CALLBACK (file_list_selection_changed_cb),
 			  data);
 
