@@ -136,7 +136,7 @@ import_dialog_response_cb (GtkDialog *dialog,
 	case GTK_RESPONSE_DELETE_EVENT:
 	case GTK_RESPONSE_CANCEL:
 		picasa_web_accounts_save_to_file (data->accounts, data->email);
-		gtk_widget_destroy (data->dialog);
+		gth_file_list_cancel (GTH_FILE_LIST (data->file_list), (DataFunc) gtk_widget_destroy, data->dialog);
 		break;
 
 	case GTK_RESPONSE_OK:
@@ -157,6 +157,7 @@ import_dialog_response_cb (GtkDialog *dialog,
 			file_list = get_files_to_download (data);
 			if (file_list != NULL) {
 				GFile               *destination;
+				GError              *error = NULL;
 				gboolean             single_subfolder;
 				GthSubfolderType     subfolder_type;
 				GthSubfolderFormat   subfolder_format;
@@ -166,6 +167,18 @@ import_dialog_response_cb (GtkDialog *dialog,
 				GthTask             *task;
 
 				destination = gth_import_preferences_get_destination ();
+
+				if (! gth_import_task_check_free_space (destination, file_list, &error)) {
+					_gtk_error_dialog_from_gerror_show (GTK_WINDOW (data->dialog),
+									    _("Could not import the files"),
+									    error);
+					g_clear_error (&error);
+					_g_object_unref (destination);
+					_g_object_list_unref (file_list);
+					g_object_unref (album);
+					return;
+				}
+
 				subfolder_type = eel_gconf_get_enum (PREF_IMPORT_SUBFOLDER_TYPE, GTH_TYPE_SUBFOLDER_TYPE, GTH_SUBFOLDER_TYPE_FILE_DATE);
 				subfolder_format = eel_gconf_get_enum (PREF_IMPORT_SUBFOLDER_FORMAT, GTH_TYPE_SUBFOLDER_FORMAT, GTH_SUBFOLDER_FORMAT_YYYYMMDD);
 				single_subfolder = eel_gconf_get_boolean (PREF_IMPORT_SUBFOLDER_SINGLE, FALSE);
@@ -291,7 +304,8 @@ list_albums_ready_cb (GObject      *source_object,
 	if (error != NULL) {
 		if (data->conn != NULL)
 			gth_task_dialog (GTH_TASK (data->conn), TRUE, NULL);
-		_gtk_error_dialog_from_gerror_show (GTK_WINDOW (data->browser), _("Could not get the album list"), &error);
+		_gtk_error_dialog_from_gerror_show (GTK_WINDOW (data->browser), _("Could not get the album list"), error);
+		g_clear_error (&error);
 		gtk_widget_destroy (data->dialog);
 		return;
 	}
@@ -305,14 +319,20 @@ list_albums_ready_cb (GObject      *source_object,
 static void
 get_album_list (DialogData *data)
 {
+	char *user_id;
+
+	gth_task_dialog (GTH_TASK (data->conn), FALSE, NULL);
+
 	if (data->picasaweb == NULL)
 		data->picasaweb = picasa_web_service_new (data->conn);
-	gth_task_dialog (GTH_TASK (data->conn), FALSE, NULL);
+	user_id = google_utils_get_user_id_from_email (data->email);
 	picasa_web_service_list_albums (data->picasaweb,
-				        "default",
+					user_id,
 				        data->cancellable,
 				        list_albums_ready_cb,
 				        data);
+
+	g_free (user_id);
 }
 
 
@@ -354,7 +374,8 @@ connection_ready_cb (GObject      *source_object,
 		else {
 			if (data->conn != NULL)
 				gth_task_dialog (GTH_TASK (data->conn), TRUE, NULL);
-			_gtk_error_dialog_from_gerror_show (GTK_WINDOW (data->browser), _("Could not connect to the server"), &error);
+			_gtk_error_dialog_from_gerror_show (GTK_WINDOW (data->browser), _("Could not connect to the server"), error);
+			g_clear_error (&error);
 			gtk_widget_destroy (data->dialog);
 		}
 		return;
@@ -445,6 +466,10 @@ account_properties_dialog (DialogData *data,
 	if ((error != NULL) && (data->accounts != NULL) && (data->accounts->next != NULL))
 		picasa_account_properties_dialog_can_choose (PICASA_ACCOUNT_PROPERTIES_DIALOG (dialog), TRUE);
 
+	g_signal_connect (dialog,
+			  "delete-event",
+			  G_CALLBACK (gtk_true),
+			  NULL);
 	g_signal_connect (dialog,
 			  "response",
 			  G_CALLBACK (account_properties_dialog_response_cb),
@@ -571,6 +596,10 @@ challange_account_dialog (DialogData *data,
 	if ((error != NULL) && (data->accounts != NULL) && (data->accounts->next != NULL))
 		picasa_account_properties_dialog_can_choose (PICASA_ACCOUNT_PROPERTIES_DIALOG (dialog), TRUE);
 
+	g_signal_connect (dialog,
+			  "delete-event",
+			  G_CALLBACK (gtk_true),
+			  NULL);
 	g_signal_connect (dialog,
 			  "response",
 			  G_CALLBACK (challange_account_dialog_response_cb),
@@ -640,6 +669,10 @@ auto_select_account (DialogData *data)
 			if (data->conn != NULL)
 				gth_task_dialog (GTH_TASK (data->conn), TRUE, NULL);
 			dialog = picasa_account_chooser_dialog_new (data->accounts, data->email);
+			g_signal_connect (dialog,
+					  "delete-event",
+					  G_CALLBACK (gtk_true),
+					  NULL);
 			g_signal_connect (dialog,
 					  "response",
 					  G_CALLBACK (account_chooser_dialog_response_cb),
@@ -697,6 +730,10 @@ edit_accounts_button_clicked_cb (GtkButton *button,
 	GtkWidget  *dialog;
 
 	dialog = picasa_account_manager_dialog_new (data->accounts);
+	g_signal_connect (dialog,
+			  "delete-event",
+			  G_CALLBACK (gtk_true),
+			  NULL);
 	g_signal_connect (dialog,
 			  "response",
 			  G_CALLBACK (account_manager_dialog_response_cb),
@@ -787,7 +824,8 @@ list_photos_ready_cb (GObject      *source_object,
 	if (error != NULL) {
 		if (data->conn != NULL)
 			gth_task_dialog (GTH_TASK (data->conn), TRUE, NULL);
-		_gtk_error_dialog_from_gerror_show (GTK_WINDOW (data->browser), _("Could not get the photo list"), &error);
+		_gtk_error_dialog_from_gerror_show (GTK_WINDOW (data->browser), _("Could not get the photo list"), error);
+		g_clear_error (&error);
 		gtk_widget_destroy (data->dialog);
 		return;
 	}
@@ -841,16 +879,19 @@ album_combobox_changed_cb (GtkComboBox *widget,
 }
 
 
-GdkPixbufAnimation *
-picasa_web_thumbnail_loader (GthFileData  *file_data,
-			     GError      **error,
-			     gpointer      data)
+GthImage *
+picasa_web_thumbnail_loader (GthFileData   *file_data,
+			     int            requested_size,
+			     int           *original_width,
+			     int           *original_height,
+			     gpointer       user_data,
+			     GCancellable  *cancellable,
+			     GError       **error)
 {
-	GdkPixbufAnimation *animation = NULL;
-	GthThumbLoader     *thumb_loader = data;
-	int                 requested_size;
-	PicasaWebPhoto     *photo;
-	const char         *uri;
+	GthImage       *image = NULL;
+	GthThumbLoader *thumb_loader = user_data;
+	PicasaWebPhoto *photo;
+	const char     *uri;
 
 	photo = (PicasaWebPhoto *) g_file_info_get_attribute_object (file_data->info, "gphoto::object");
 	requested_size = gth_thumb_loader_get_requested_size (thumb_loader);
@@ -872,12 +913,12 @@ picasa_web_thumbnail_loader (GthFileData  *file_data,
 		gsize  size;
 
 		file = g_file_new_for_uri (uri);
-		if (g_load_file_in_buffer (file, &buffer, &size, error)) {
+		if (g_load_file_in_buffer (file, &buffer, &size, cancellable, error)) {
 			GInputStream *stream;
 			GdkPixbuf    *pixbuf;
 
 			stream = g_memory_input_stream_new_from_data (buffer, size, g_free);
-			pixbuf = gdk_pixbuf_new_from_stream (stream, NULL, error);
+			pixbuf = gdk_pixbuf_new_from_stream (stream, cancellable, error);
 			if (pixbuf != NULL) {
 				GdkPixbuf *rotated;
 
@@ -885,7 +926,7 @@ picasa_web_thumbnail_loader (GthFileData  *file_data,
 				g_object_unref (pixbuf);
 				pixbuf = rotated;
 
-				animation = gdk_pixbuf_non_anim_new (pixbuf);
+				image = gth_image_new_for_pixbuf (pixbuf);
 			}
 
 			g_object_unref (pixbuf);
@@ -897,7 +938,7 @@ picasa_web_thumbnail_loader (GthFileData  *file_data,
 	else
 		*error = g_error_new_literal (GTH_ERROR, 0, "cannot generate the thumbnail");
 
-	return animation;
+	return image;
 }
 
 
@@ -970,13 +1011,14 @@ dlg_import_from_picasaweb (GthBrowser *browser)
 
 	/* Set the widget data */
 
-	data->file_list = gth_file_list_new (GTH_FILE_LIST_TYPE_NORMAL, FALSE);
+	data->file_list = gth_file_list_new (gth_icon_view_new (), GTH_FILE_LIST_TYPE_NORMAL, FALSE);
 	thumb_loader = gth_file_list_get_thumb_loader (GTH_FILE_LIST (data->file_list));
-	gth_thumb_loader_use_cache (thumb_loader, FALSE);
-	gth_thumb_loader_set_loader (thumb_loader, picasa_web_thumbnail_loader);
+	gth_thumb_loader_set_use_cache (thumb_loader, FALSE);
+	gth_thumb_loader_set_loader_func (thumb_loader, picasa_web_thumbnail_loader);
 	gth_file_list_set_thumb_size (GTH_FILE_LIST (data->file_list), PICASA_WEB_THUMB_SIZE_SMALL);
 	gth_file_view_set_spacing (GTH_FILE_VIEW (gth_file_list_get_view (GTH_FILE_LIST (data->file_list))), 0);
 	gth_file_list_enable_thumbs (GTH_FILE_LIST (data->file_list), TRUE);
+	gth_file_list_set_ignore_hidden (GTH_FILE_LIST (data->file_list), TRUE);
 	gth_file_list_set_caption (GTH_FILE_LIST (data->file_list), "none");
 	gth_file_list_set_sort_func (GTH_FILE_LIST (data->file_list), picasa_web_photo_position_func, FALSE);
 	gth_file_list_clear (GTH_FILE_LIST (data->file_list), _("No album selected"));
@@ -1003,6 +1045,10 @@ dlg_import_from_picasaweb (GthBrowser *browser)
 			  "destroy",
 			  G_CALLBACK (import_dialog_destroy_cb),
 			  data);
+	g_signal_connect (data->dialog,
+			  "delete-event",
+			  G_CALLBACK (gtk_true),
+			  NULL);
 	g_signal_connect (data->dialog,
 			  "response",
 			  G_CALLBACK (import_dialog_response_cb),
@@ -1020,7 +1066,7 @@ dlg_import_from_picasaweb (GthBrowser *browser)
 			  G_CALLBACK (album_combobox_changed_cb),
 			  data);
 	g_signal_connect (G_OBJECT (gth_file_list_get_view (GTH_FILE_LIST (data->file_list))),
-			  "selection_changed",
+			  "file-selection-changed",
 			  G_CALLBACK (file_list_selection_changed_cb),
 			  data);
 
