@@ -311,7 +311,8 @@ filter_editor_dialog__response_cb (GtkDialog *dialog,
 
 	filter = gth_filter_editor_dialog_get_filter (GTH_FILTER_EDITOR_DIALOG (dialog), &error);
 	if (filter == NULL) {
-		_gtk_error_dialog_from_gerror_show (GTK_WINDOW (dialog), _("Could not save the filter"), &error);
+		_gtk_error_dialog_from_gerror_show (GTK_WINDOW (dialog), _("Could not save the filter"), error);
+		g_clear_error (&error);
 		return;
 	}
 
@@ -522,7 +523,7 @@ dlg_personalize_filters (GthBrowser *browser)
 	general_filter = eel_gconf_get_string (PREF_GENERAL_FILTER, DEFAULT_GENERAL_FILTER);
 	active_filter = 0;
 
-	data->general_filter_combobox = gtk_combo_box_new_text ();
+	data->general_filter_combobox = gtk_combo_box_text_new ();
 	for (i = 0, i_general = -1, scan = tests; scan; scan = scan->next, i++) {
 		const char *registered_test_id = scan->data;
 		GthTest    *test;
@@ -537,7 +538,7 @@ dlg_personalize_filters (GthBrowser *browser)
 
 		test = gth_main_get_registered_object (GTH_TYPE_TEST, registered_test_id);
 		data->general_tests = g_list_prepend (data->general_tests, g_strdup (gth_test_get_id (test)));
-		gtk_combo_box_append_text (GTK_COMBO_BOX (data->general_filter_combobox), gth_test_get_display_name (test));
+		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (data->general_filter_combobox), gth_test_get_display_name (test));
 		g_object_unref (test);
 	}
 	data->general_tests = g_list_reverse (data->general_tests);
