@@ -123,7 +123,7 @@ update_sensitivity (GthFilterEditorDialog *self)
 {
 	gboolean  active;
 	GList    *test_selectors;
-	int       more_selectors;
+	int       many_selectors;
 	GList    *scan;
 
 	active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("limit_to_checkbutton")));
@@ -135,9 +135,9 @@ update_sensitivity (GthFilterEditorDialog *self)
 	gtk_widget_set_sensitive (GET_WIDGET ("tests_box"), active);
 
 	test_selectors = gtk_container_get_children (GTK_CONTAINER (GET_WIDGET ("tests_box")));
-	more_selectors = (test_selectors != NULL) && (test_selectors->next != NULL);
+	many_selectors = (test_selectors != NULL) && (test_selectors->next != NULL);
 	for (scan = test_selectors; scan; scan = scan->next)
-		gth_test_selector_can_remove (GTH_TEST_SELECTOR (scan->data), more_selectors);
+		gth_test_selector_can_remove (GTH_TEST_SELECTOR (scan->data), many_selectors);
 	g_list_free (test_selectors);
 }
 
@@ -176,7 +176,6 @@ gth_filter_editor_dialog_construct (GthFilterEditorDialog *self,
   	if (parent != NULL)
     		gtk_window_set_transient_for (GTK_WINDOW (self), parent);
     	gtk_window_set_resizable (GTK_WINDOW (self), FALSE);
-	gtk_dialog_set_has_separator (GTK_DIALOG (self), FALSE);
 	gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (self))), 5);
 	gtk_container_set_border_width (GTK_CONTAINER (self), 5);
 
@@ -191,8 +190,8 @@ gth_filter_editor_dialog_construct (GthFilterEditorDialog *self,
 
 	/**/
 
-  	self->priv->match_type_combobox = gtk_combo_box_new_text ();
-  	_gtk_combo_box_append_texts (GTK_COMBO_BOX (self->priv->match_type_combobox),
+  	self->priv->match_type_combobox = gtk_combo_box_text_new ();
+  	_gtk_combo_box_append_texts (GTK_COMBO_BOX_TEXT (self->priv->match_type_combobox),
   				     _("all the following rules"),
   				     _("any of the following rules"),
   				     NULL);
@@ -203,8 +202,8 @@ gth_filter_editor_dialog_construct (GthFilterEditorDialog *self,
 
 	/**/
 
-  	self->priv->limit_object_combobox = gtk_combo_box_new_text ();
-  	_gtk_combo_box_append_texts (GTK_COMBO_BOX (self->priv->limit_object_combobox),
+  	self->priv->limit_object_combobox = gtk_combo_box_text_new ();
+  	_gtk_combo_box_append_texts (GTK_COMBO_BOX_TEXT (self->priv->limit_object_combobox),
   				     _("files"),
   				     _("kB"),
   				     _("MB"),
@@ -238,7 +237,7 @@ gth_filter_editor_dialog_construct (GthFilterEditorDialog *self,
 		gtk_list_store_append (selection_model, &iter);
 		gtk_list_store_set (selection_model, &iter,
 				    SELECTION_COLUMN_DATA, sort_type,
-				    SELECTION_COLUMN_NAME, sort_type->display_name,
+				    SELECTION_COLUMN_NAME, _(sort_type->display_name),
 				    -1);
 	}
 	g_list_free (sort_types);
@@ -250,8 +249,8 @@ gth_filter_editor_dialog_construct (GthFilterEditorDialog *self,
 
 	/**/
 
-	self->priv->selection_order_combobox = gtk_combo_box_new_text ();
-  	_gtk_combo_box_append_texts (GTK_COMBO_BOX (self->priv->selection_order_combobox),
+	self->priv->selection_order_combobox = gtk_combo_box_text_new ();
+  	_gtk_combo_box_append_texts (GTK_COMBO_BOX_TEXT (self->priv->selection_order_combobox),
   				     _("ascending"),
   				     _("descending"),
   				     NULL);
@@ -359,7 +358,7 @@ _gth_filter_editor_dialog_set_new_filter (GthFilterEditorDialog *self)
 }
 
 
-gboolean
+static gboolean
 get_iter_for_sort_type (GthFilterEditorDialog *self,
 			const char            *sort_type_name,
 			GtkTreeIter           *iter)
