@@ -37,6 +37,12 @@
 #include "pixbuf-io.h"
 #include "typedefs.h"
 
+#ifdef GDK_WINDOWING_X11
+#include <gdk/gdkx.h>
+#endif
+
+#include "eggsmclient.h"
+#include "eggdesktopfile.h"
 
 static GStaticMutex register_mutex = G_STATIC_MUTEX_INIT;
 
@@ -98,7 +104,7 @@ struct _GthMainPrivate
 	GHashTable          *metadata_info_hash;
 	gboolean             metadata_info_sorted;
 	GHashTable          *sort_types;
-	GHashTable          *loaders;
+	GHashTable          *image_loaders;
 	GHashTable          *types;
 	GHashTable          *classes;
 	GHashTable          *objects_order;
@@ -129,8 +135,8 @@ gth_main_finalize (GObject *object)
 
 		if (gth_main->priv->sort_types != NULL)
 			g_hash_table_unref (gth_main->priv->sort_types);
-		if (gth_main->priv->loaders != NULL)
-			g_hash_table_unref (gth_main->priv->loaders);
+		if (gth_main->priv->image_loaders != NULL)
+			g_hash_table_unref (gth_main->priv->image_loaders);
 		if (gth_main->priv->types != NULL)
 			g_hash_table_unref (gth_main->priv->types);
 		if (gth_main->priv->classes != NULL)
@@ -169,11 +175,11 @@ static void
 gth_main_init (GthMain *main)
 {
 	main->priv = g_new0 (GthMainPrivate, 1);
-	main->priv->sort_types = g_hash_table_new_full (g_str_hash,
-							g_str_equal,
-							NULL,
-							NULL);
-	main->priv->loaders = g_hash_table_new (g_str_hash, (GEqualFunc) g_content_type_equals);
+	main->priv->sort_types = g_hash_table_new_full (g_str_hash, g_str_equal, NULL, NULL);
+	main->priv->image_loaders = g_hash_table_new_full (g_str_hash,
+						           (GEqualFunc) g_content_type_equals,
+						           g_free,
+						           NULL);
 	main->priv->metadata_category = g_ptr_array_new ();
 	main->priv->metadata_info = g_ptr_array_new ();
 	main->priv->metadata_info_hash = g_hash_table_new_full (g_str_hash, g_str_equal, NULL, NULL);
@@ -209,46 +215,6 @@ gth_main_get_type (void)
 }
 
 
-static void
-about_dialog_activate_link_cb (GtkAboutDialog *about,
-			       const char     *link_,
-			       gpointer        data)
-{
-	GError *error = NULL;
-
-	if (! gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (about)), link_, GDK_CURRENT_TIME, &error)) {
-		char *title;
-
-		title = g_strdup_printf (_("Unable to show '%s'"), link_);
-		_gtk_error_dialog_from_gerror_run (GTK_WINDOW (about), title, &error);
-
-		g_free (title);
-	}
-}
-
-
-static void
-about_dialog_activate_email_cb (GtkAboutDialog *about,
-			        const char     *link_,
-			        gpointer        data)
-{
-	GError *error = NULL;
-	char   *url;
-
-	url = g_strconcat ("mailto:", link_, NULL);
-	if (! gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (about)), url, GDK_CURRENT_TIME, &error)) {
-		char *title;
-
-		title = g_strdup_printf (_("Unable to open '%s'"), link_);
-		_gtk_error_dialog_from_gerror_run (GTK_WINDOW (about), title, &error);
-
-		g_free (title);
-	}
-
-	g_free (url);
-}
-
-
 void
 gth_main_initialize (void)
 {
@@ -256,11 +222,15 @@ gth_main_initialize (void)
 		return;
 	Main = (GthMain*) g_object_new (GTH_TYPE_MAIN, NULL);
 
-	g_set_application_name (_("gthumb"));
+#ifdef GDK_WINDOWING_X11
+	egg_set_desktop_file (GTHUMB_APPLICATIONS_DIR "/gthumb.desktop");
+#else
+	/* manually set name and icon */
+	g_set_application_name (_("gThumb"));
 	gtk_window_set_default_icon_name ("gthumb");
+#endif
+
 	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (), GTHUMB_ICON_DIR);
-	gtk_about_dialog_set_url_hook (about_dialog_activate_link_cb, NULL, NULL);
-	gtk_about_dialog_set_email_hook (about_dialog_activate_email_cb, NULL, NULL);
 }
 
 
@@ -731,9 +701,10 @@ _gth_main_create_type_spec (GType       object_type,
 
 
 void
-gth_main_register_pixbuf_loader (PixbufLoader  loader,
-			         const char   *first_mime_type,
-			         ...)
+gth_main_register_image_loader_func (GthImageLoaderFunc  loader,
+				     GthImageFormat      native_format,
+				     const char         *first_mime_type,
+				     ...)
 {
 	va_list     var_args;
 	const char *mime_type;
@@ -743,7 +714,11 @@ gth_main_register_pixbuf_loader (PixbufLoader  loader,
 	va_start (var_args, first_mime_type);
 	mime_type = first_mime_type;
   	while (mime_type != NULL) {
-		g_hash_table_insert (Main->priv->loaders, (gpointer) get_static_string (g_content_type_from_mime_type (mime_type)), loader);
+  		char *key;
+
+  		key = g_strdup_printf ("%s-%d", mime_type, native_format);
+		g_hash_table_insert (Main->priv->image_loaders, (gpointer) key, loader);
+
 		mime_type = va_arg (var_args, const char *);
   	}
 	va_end (var_args);
@@ -752,13 +727,31 @@ gth_main_register_pixbuf_loader (PixbufLoader  loader,
 }
 
 
-PixbufLoader
-gth_main_get_pixbuf_loader (const char *mime_type)
+GthImageLoaderFunc
+gth_main_get_image_loader_func (const char     *mime_type,
+				GthImageFormat  preferred_format)
 {
-	if (mime_type != NULL)
-		return (PixbufLoader) g_hash_table_lookup (Main->priv->loaders, mime_type);
-	else
-		return NULL;
+	GthImageLoaderFunc  loader;
+	char               *key;
+	int                 format;
+
+	/* give priority to the preferred format */
+
+	key = g_strdup_printf ("%s-%d", mime_type, preferred_format);
+	loader = g_hash_table_lookup (Main->priv->image_loaders, key);
+
+	/* if the preferred format is not available, search another
+	 * format. */
+
+	for (format = 0; (loader == NULL) && (format < GTH_IMAGE_N_FORMATS); format++) {
+		g_free (key);
+		key = g_strdup_printf ("%s-%d", mime_type, format);
+		loader = g_hash_table_lookup (Main->priv->image_loaders, key);
+	}
+
+	g_free (key);
+
+	return loader;
 }
 
 
@@ -1191,7 +1184,7 @@ gth_main_tags_changed (void)
 GthMonitor *
 gth_main_get_default_monitor (void)
 {
-	if (Main->priv->monitor != NULL)
+	if (G_LIKELY (Main->priv->monitor != NULL))
 		return Main->priv->monitor;
 
 	Main->priv->monitor = gth_monitor_new ();
@@ -1211,12 +1204,14 @@ void
 gth_main_activate_extensions (void)
 {
 	const char *mandatory_extensions[] = {	"file_viewer",
+						"cairo_io",
 						NULL };
 	const char *default_extensions[] = {	"bookmarks",
 						"burn_disc",
 						"catalogs",
 						"change_date",
 						"comments",
+						"contact_sheet",
 						"convert_format",
 						"desktop_background",
 						"edit_metadata",
@@ -1224,6 +1219,7 @@ gth_main_activate_extensions (void)
 						"facebook",
 						"file_manager",
 						"file_tools",
+						"find_duplicates",
 						"flicker",
 						"gstreamer_tools",
 						"gstreamer_utils",
@@ -1325,12 +1321,15 @@ attribute_list_reload_required (const char *old_attributes,
 	int        i;
 	gboolean   reload_required;
 
+	if (old_attributes == NULL)
+		return TRUE;
+
 	old_attributes_v = g_strsplit (old_attributes, ",", -1);
 	new_attributes_v = g_strsplit (new_attributes, ",", -1);
 	new_attributes_len = g_strv_length (new_attributes_v);
 
 	for (i = 0; i < new_attributes_len; i++) {
-		if (_g_file_attributes_matches_any (new_attributes_v[i], GIO_ATTRIBUTES)) {
+		if (_g_utf8_all_spaces (new_attributes_v[i]) || _g_file_attributes_matches_any (new_attributes_v[i], GIO_ATTRIBUTES)) {
 			g_free (new_attributes_v[i]);
 			new_attributes_v[i] = NULL;
 		}
